# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from . import utilities, tables

class RemoteImage(pulumi.CustomResource):
    keep_locally: pulumi.Output[bool]
    """
    If true, then the Docker image won't be
    deleted on destroy operation. If this is false, it will delete the image from
    the docker local storage on destroy operation.
    """
    latest: pulumi.Output[str]
    name: pulumi.Output[str]
    """
    The name of the Docker image, including any tags or SHA256 repo digests.
    """
    pull_trigger: pulumi.Output[str]
    """
    **Deprecated**, use `pull_triggers` instead.
    """
    pull_triggers: pulumi.Output[list]
    """
    List of values which cause an
    image pull when changed. This is used to store the image digest from the
    registry when using the `docker_registry_image` [data source](https://www.terraform.io/docs/providers/docker/d/registry_image.html)
    to trigger an image update.
    """
    def __init__(__self__, resource_name, opts=None, keep_locally=None, name=None, pull_trigger=None, pull_triggers=None, __name__=None, __opts__=None):
        """
        Pulls a Docker image to a given Docker host from a Docker Registry.
        
        This resource will *not* pull new layers of the image automatically unless used in
        conjunction with [`docker_registry_image`](https://www.terraform.io/docs/providers/docker/d/registry_image.html)
        data source to update the `pull_triggers` field.
        
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] keep_locally: If true, then the Docker image won't be
               deleted on destroy operation. If this is false, it will delete the image from
               the docker local storage on destroy operation.
        :param pulumi.Input[str] name: The name of the Docker image, including any tags or SHA256 repo digests.
        :param pulumi.Input[str] pull_trigger: **Deprecated**, use `pull_triggers` instead.
        :param pulumi.Input[list] pull_triggers: List of values which cause an
               image pull when changed. This is used to store the image digest from the
               registry when using the `docker_registry_image` [data source](https://www.terraform.io/docs/providers/docker/d/registry_image.html)
               to trigger an image update.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['keep_locally'] = keep_locally

        if name is None:
            raise TypeError('Missing required property name')
        __props__['name'] = name

        __props__['pull_trigger'] = pull_trigger

        __props__['pull_triggers'] = pull_triggers

        __props__['latest'] = None

        super(RemoteImage, __self__).__init__(
            'docker:index/remoteImage:RemoteImage',
            resource_name,
            __props__,
            opts)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

